@@ -16,9 +16,6 @@ noundict = {
     "us": "we",
     "me": "i",
 }
-nlp = spacy.load("en_core_web_sm")
-matcher = Matcher(nlp.vocab)
-
 
 def nouninv(noun):
     n = noun.lower()
@@ -26,23 +23,23 @@ def nouninv(noun):
         return noundict[n]
     return noun
 
-
 def pattern_stopiteration_workaround():
     try:
-        print(lexeme("check"))
+        print(lexeme('check'))
     except:
         pass
 
-
-pattern_stopiteration_workaround()
-
-
-def pass2act(doc, rec=False):
+pattern_stopiteration_workaround()    
+    
+def pass2act(doc, nlp, rec=False):
     """
     Author : Daniel Nohimovich & Zhekai Jin (Scott)
     Course : ECE 467 Natural Language Processing
     Instructor : Professor Carl Sable
     https://github.com/DanManN/pass2act
+    All rights reserved by the orignal author.
+    This source code is licensed under the Apache License 2.0 found in the
+    LICENSE file in the root directory of this source tree.
     """
     parse = nlp(doc)
     newdoc = ""
@@ -280,7 +277,7 @@ def pass2act(doc, rec=False):
     return newdoc
 
 
-def is_passive(sentence):
+def is_passive(sentence, nlp):
     doc = nlp(sentence)
     passive_rule = [
         {"DEP": "nsubjpass"},
@@ -288,7 +285,10 @@ def is_passive(sentence):
         {"DEP": "auxpass"},
         {"TAG": "VBN"},
     ]
-    matcher.add("Passive", None, passive_rule)
+
+    matcher = Matcher(nlp.vocab)
+
+    matcher.add("Passive", [passive_rule])
     matches = matcher(doc)
     if matches:
         return True
